@@ -19,6 +19,8 @@ import sys
 
 from osc_lib.tests import utils
 
+from tripleoclient import plugin
+
 AUTH_TOKEN = "foobar"
 AUTH_URL = "http://0.0.0.0"
 WS_URL = "ws://0.0.0.0"
@@ -183,6 +185,7 @@ class FakeClientManager(object):
         self.auth_ref = None
         self.tripleoclient = FakeClientWrapper()
         self.workflow_engine = mock.Mock()
+        self.create_mistral_context = mock.Mock()
 
 
 class FakeHandle(object):
@@ -285,6 +288,9 @@ class FakePlaybookExecution(utils.TestCommand):
         self.tripleoclient = mock.Mock()
         stack = self.app.client_manager.orchestration = mock.Mock()
         stack.stacks.get.return_value = FakeStackObject
+        tc = self.app.client_manager.tripleoclient = FakeClientWrapper()
+        tc.create_mistral_context = plugin.ClientWrapper(
+             instance=FakeInstanceData).create_mistral_context
 
         get_key = mock.patch('tripleoclient.utils.get_key')
         get_key.start()
@@ -324,3 +330,84 @@ class FakePlaybookExecution(utils.TestCommand):
 def fake_ansible_runner_run_return(rc=0):
 
     return 'Test Status', rc
+
+
+class FakeNeutronNetwork(dict):
+    def __init__(self, **attrs):
+        NETWORK_ATTRS = ['id',
+                         'name',
+                         'status',
+                         'tenant_id',
+                         'is_admin_state_up',
+                         'mtu',
+                         'segments',
+                         'is_shared',
+                         'subnet_ids',
+                         'provider:network_type',
+                         'provider:physical_network',
+                         'provider:segmentation_id',
+                         'router:external',
+                         'availability_zones',
+                         'availability_zone_hints',
+                         'is_default',
+                         'tags']
+
+        raw = dict.fromkeys(NETWORK_ATTRS)
+        raw.update(attrs)
+        raw.update({
+            'provider_physical_network': attrs.get(
+                'provider:physical_network', None),
+            'provider_network_type': attrs.get(
+                'provider:network_type', None),
+            'provider_segmentation_id': attrs.get(
+                'provider:segmentation_id', None)
+        })
+        super(FakeNeutronNetwork, self).__init__(raw)
+
+    def __getattr__(self, key):
+        try:
+            return self[key]
+        except KeyError:
+            raise AttributeError(key)
+
+    def __setattr__(self, key, value):
+        if key in self:
+            self[key] = value
+        else:
+            raise AttributeError(key)
+
+
+class FakeNeutronSubnet(dict):
+    def __init__(self, **attrs):
+        SUBNET_ATTRS = ['id',
+                        'name',
+                        'network_id',
+                        'cidr',
+                        'tenant_id',
+                        'is_dhcp_enabled',
+                        'dns_nameservers',
+                        'allocation_pools',
+                        'host_routes',
+                        'ip_version',
+                        'gateway_ip',
+                        'ipv6_address_mode',
+                        'ipv6_ra_mode',
+                        'subnetpool_id',
+                        'segment_id',
+                        'tags']
+
+        raw = dict.fromkeys(SUBNET_ATTRS)
+        raw.update(attrs)
+        super(FakeNeutronSubnet, self).__init__(raw)
+
+    def __getattr__(self, key):
+        try:
+            return self[key]
+        except KeyError:
+            raise AttributeError(key)
+
+    def __setattr__(self, key, value):
+        if key in self:
+            self[key] = value
+        else:
+            raise AttributeError(key)
