@@ -17,6 +17,7 @@ import fixtures
 import json
 import mock
 import os
+import sys
 
 from jinja2 import Template
 
@@ -91,12 +92,8 @@ class TestUndercloudInstall(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -154,12 +151,8 @@ class TestUndercloudInstall(TestPluginV1):
              '/home/stack/foo.yaml', '-e',
              '/usertht/environments/services/ironic.yaml', '-e',
              '/usertht/environments/services/ironic-inspector.yaml', '-e',
-             '/usertht/environments/'
-             'disable-heat.yaml', '-e',
              '/usertht/environments/services/'
              'undercloud-remove-novajoin.yaml', '-e',
-             '/usertht/environments/'
-             'disable-telemetry.yaml', '-e',
              '/usertht/environments/public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -318,12 +311,8 @@ class TestUndercloudInstall(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '4.3.2.1',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -384,12 +373,8 @@ class TestUndercloudInstall(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -446,12 +431,8 @@ class TestUndercloudInstall(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -505,12 +486,8 @@ class TestUndercloudInstall(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/barbican.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'barbican-backend-simple-crypto.yaml', '-e',
@@ -550,6 +527,7 @@ class TestUndercloudUpgrade(TestPluginV1):
 
     @mock.patch('tripleoclient.utils.prompt_user_for_confirmation',
                 return_value=True)
+    @mock.patch.object(sys, 'executable', 'python2')
     # TODO(cjeanner) drop once we have proper oslo.privsep
     @mock.patch('os.geteuid', return_value=1001)
     @mock.patch('getpass.getuser', return_value='stack')
@@ -570,7 +548,7 @@ class TestUndercloudUpgrade(TestPluginV1):
         self.cmd.take_action(parsed_args)
         mock_run_command.assert_called_with(
             ['sudo', 'dnf', 'upgrade', '-y',
-             'python3-tripleoclient',
+             'python2-tripleoclient',
              'openstack-tripleo-common',
              'openstack-tripleo-heat-templates',
              'openstack-tripleo-validations',
@@ -599,12 +577,8 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -621,6 +595,7 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/'
              'undercloud-stack-vstate-dropin.yaml'])
 
+    @mock.patch.object(sys, 'executable', 'python3')
     # TODO(cjeanner) drop once we have proper oslo.privsep
     @mock.patch('os.geteuid', return_value=1001)
     @mock.patch('getpass.getuser', return_value='stack')
@@ -688,12 +663,8 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -754,12 +725,8 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -819,12 +786,8 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -882,12 +845,8 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
@@ -951,12 +910,8 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic-inspector.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-heat.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/undercloud-remove-novajoin.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'disable-telemetry.yaml', '-e',
-             '/usr/share/openstack-tripleo-heat-templates/environments/'
              'public-tls-undercloud.yaml',
              '--public-virtual-ip', '192.168.24.2',
              '--control-virtual-ip', '192.168.24.3', '-e',
