@@ -12,13 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import json
 import logging
 import netaddr
 import netifaces
 import os
 import subprocess
 import sys
-import yaml
 
 from osc_lib.i18n import _
 
@@ -95,7 +95,7 @@ def _check_diskspace(upgrade=False):
             inventory='undercloud',
             log_path=tmp,
             validations_dir=constants.ANSIBLE_VALIDATION_DIR,
-            validation_name=[playbook_args['playbook']])
+            validation_name=playbook_args['playbook'])
 
 
 def _check_memory():
@@ -300,8 +300,8 @@ def _validate_no_ip_change():
             os.path.expanduser(os_net_config_file)):
         return
     try:
-        with open(os_net_config_file, 'r') as f:
-            network_config = yaml.safe_load(f)
+        with open(os_net_config_file) as f:
+            network_config = json.loads(f.read())
         ctlplane = [i for i in network_config.get('network_config', [])
                     if i.get('name') == 'br-ctlplane'][0]
 
@@ -312,10 +312,7 @@ def _validate_no_ip_change():
         # Nothing to check if br-ctlplane wasn't configured
         return
     existing_ip = ctlplane['addresses'][0]['ip_netmask']
-    conf_netaddr = netaddr.IPNetwork(CONF.local_ip)
-    existing_netaddr = netaddr.IPNetwork(existing_ip)
-    if (conf_netaddr != existing_netaddr
-            or conf_netaddr.ip != existing_netaddr.ip):
+    if existing_ip != CONF.local_ip:
         message = _('Changing the local_ip is not allowed.  Existing IP: '
                     '{0}, Configured IP: {1}').format(
                         existing_ip, CONF.local_ip)
@@ -329,29 +326,18 @@ def _validate_passwords_file():
     If the undercloud was already deployed, the passwords file needs to be
     present so passwords that can't be changed are persisted.  If the file
     is missing it will break the undercloud, so we should fail-fast and let
-    the user know about the problem.  Both the old and new path to the file
-    is checked.  If either is found, the validation will pass as the old
-    path will be migrated to the new during and update/upgrade.
+    the user know about the problem.
     """
-    old_passwd_path = None
-    file_name = 'tripleo-undercloud-passwords.yaml'
-
     if not CONF.get('output_dir'):
         output_dir = os.path.join(constants.UNDERCLOUD_OUTPUT_DIR,
                                   'tripleo-deploy', 'undercloud')
     else:
         output_dir = CONF['output_dir']
-        old_passwd_path = os.path.join(output_dir, file_name)
-
-    # If old_passwd_path is not yet set, then default to the old path
-    if not old_passwd_path:
-        old_passwd_path = os.path.join(constants.CLOUD_HOME_DIR, file_name)
-
-    passwd_path = os.path.join(output_dir, file_name)
 
+    passwd_path = os.path.join(output_dir,
+                               'tripleo-undercloud-passwords.yaml')
     if (os.path.isfile(os.path.join(constants.CLOUD_HOME_DIR, 'stackrc')) and
-            not (os.path.isfile(passwd_path) or
-                 os.path.isfile(old_passwd_path))):
+            not os.path.isfile(passwd_path)):
         message = (_('The %s file is missing.  This will cause all service '
                      'passwords to change and break the existing '
                      'undercloud. ') % passwd_path)
@@ -418,6 +404,11 @@ def _validate_architecure_options():
         LOG.error(_('Undercloud configuration validation failed: %s'), message)
         raise FailedValidation(message)
 
+    def _validate_ppc64le_exclusive_opts(error_callback):
+        if 'ipxe_enabled' in CONF and CONF['ipxe_enabled']:
+            error_callback(_('Currently iPXE boot isn\'t supported with '
+                             'ppc64le systems but is enabled'))
+
     def _validate_additional_architectures(error_callback):
         for arch in CONF['additional_architectures']:
             if arch not in constants.ADDITIONAL_ARCHITECTURES:
@@ -430,6 +421,8 @@ def _validate_architecure_options():
                                  '%(all_architectures)s') % params)
 
     _validate_additional_architectures(error_handler)
+    if 'ppc64le' in CONF['additional_architectures']:
+        _validate_ppc64le_exclusive_opts(error_handler)
 
 
 def _checking_status(item):
